package com.inspect.metadata.prodevmnt.mapper;

import com.inspect.metadata.prodevmnt.domain.BasedataModelDevice;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface BasedataModelDeviceMapper {
    BasedataModelDevice selectBasedataModelDeviceByModelDeviceId(String deviceId);

    List<BasedataModelDevice> selectBasedataModelDeviceList(BasedataModelDevice modelDevice);

    int insertBasedataModelDevice(BasedataModelDevice modelDevice);

    int updateBasedataModelDevice(BasedataModelDevice modelDevice);

    int deleteBasedataModelDeviceByModelDeviceId(String deviceId);

    int deleteBasedataModelDeviceByModelDeviceIds(String[] deviceIds);
}
